==> cramr_ui_lib-1.0.11.tar.gz: lib/model/practice_session.dart <==
class PracticeSession {
  final DateTime _creationTime;
  final String _mode;
  final String _tense;
  final List<String> _actuals;
  final StudyMethod _studyMethod;

  PracticeSession(this._creationTime, this._mode, this._tense, this._actuals,
      this._studyMethod);

  PracticeSession.fromJson(Map<String, dynamic> json)
      : _creationTime = DateTime.parse(json['creationTime']),
        _mode = json['mode'],
        _tense = json['tense'],
        _actuals = List<String>.from(json['actuals'] as List),
        _studyMethod = StudyMethod.values.byName(json['studyMethod']);

  String get mode => _mode;
  String get tense => _tense;
  List<String> get actuals => _actuals;
  StudyMethod get studyMethod => _studyMethod;

  DateKey dateKey() {
    return DateKey(_creationTime.year, _creationTime.month, _creationTime.day);
  }

  static Map<String, dynamic> toJson(PracticeSession value) => {
        'creationTime': value._creationTime.toIso8601String(),
        'mode': value._mode,
        'tense': value._tense,
        'actuals': value._actuals,
        'studyMethod': value._studyMethod.name
      };
}

class DateKey {
  late int year;
  late int month;
  late int day;

  DateKey(this.year, this.month, this.day);

  @override
  String toString() {
    return 'DateKey{year: $year, month: $month, day: $day}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is DateKey &&
          runtimeType == other.runtimeType &&
          year == other.year &&
          month == other.month &&
          day == other.day;

  @override
  int get hashCode => year.hashCode ^ month.hashCode ^ day.hashCode;

  bool isDayBefore(DateKey arg) {
    const Duration oneDay = Duration(days: 1);
    DateTime outerDateTime = DateTime(arg.year, arg.month, arg.day);
    DateTime traveledOuterDateTime = outerDateTime.subtract(oneDay);
    DateKey traveledOuterDateKey = DateKey(traveledOuterDateTime.year,
        traveledOuterDateTime.month, traveledOuterDateTime.day);
    return this == traveledOuterDateKey;
  }

  bool isToday() {
    DateTime today = DateTime.now();
    DateKey todayKey = DateKey(today.year, today.month, today.day);
    return this == todayKey;
  }
}

enum StudyMethod { coverMethod, writtenMethod, flashcardMethod }

==> cramr_ui_lib-2.0.0.tar.gz: lib/model/practice_session.dart <==
class PracticeSession {
  final DateTime _creationTime;
  final String _mode;
  final String _tense;
  final List<String> _actuals;
  final StudyMethod _studyMethod;
  late final String? _infinitive;

  PracticeSession(this._creationTime, this._mode, this._tense, this._actuals,
      this._studyMethod,
      [this._infinitive]);

  PracticeSession.fromJson(Map<String, dynamic> json)
      : _creationTime = DateTime.parse(json['creationTime']),
        _mode = json['mode'],
        _tense = json['tense'],
        _actuals = List<String>.from(json['actuals'] as List),
        _studyMethod = StudyMethod.values.byName(json['studyMethod']),
        _infinitive = json['infinitive'];

  String get mode => _mode;
  String get tense => _tense;
  List<String> get actuals => _actuals;
  StudyMethod get studyMethod => _studyMethod;
  String? get infinitive => _infinitive;

  DateKey dateKey() {
    return DateKey(_creationTime.year, _creationTime.month, _creationTime.day);
  }

  static Map<String, dynamic> toJson(PracticeSession value) => {
        'creationTime': value._creationTime.toIso8601String(),
        'mode': value._mode,
        'tense': value._tense,
        'actuals': value._actuals,
        'studyMethod': value._studyMethod.name,
        'infinitive': value._infinitive
      };
}

class DateKey {
  late int year;
  late int month;
  late int day;

  DateKey(this.year, this.month, this.day);

  @override
  String toString() {
    return 'DateKey{year: $year, month: $month, day: $day}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is DateKey &&
          runtimeType == other.runtimeType &&
          year == other.year &&
          month == other.month &&
          day == other.day;

  @override
  int get hashCode => year.hashCode ^ month.hashCode ^ day.hashCode;

  bool isDayBefore(DateKey arg) {
    const Duration oneDay = Duration(days: 1);
    DateTime outerDateTime = DateTime(arg.year, arg.month, arg.day);
    DateTime traveledOuterDateTime = outerDateTime.subtract(oneDay);
    DateKey traveledOuterDateKey = DateKey(traveledOuterDateTime.year,
        traveledOuterDateTime.month, traveledOuterDateTime.day);
    return this == traveledOuterDateKey;
  }

  bool isToday() {
    DateTime today = DateTime.now();
    DateKey todayKey = DateKey(today.year, today.month, today.day);
    return this == todayKey;
  }
}

enum StudyMethod { coverMethod, writtenMethod, flashcardMethod }

class SessionConjugation {
  final String _mode;
  final String _tense;

  SessionConjugation(this._mode, this._tense);

  String get mode => _mode;
  String get tense => _tense;

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is SessionConjugation &&
          runtimeType == other.runtimeType &&
          _mode == other._mode &&
          _tense == other._tense;

  @override
  int get hashCode => _mode.hashCode ^ _tense.hashCode;
}
